==> atlassian-aws-1.0.163-sources.jar: com/atlassian/aws/ec2/InstanceLaunchConfigurationBuilder.java <==
package com.atlassian.aws.ec2;

import com.amazonaws.services.ec2.model.IamInstanceProfileSpecification;
import com.atlassian.aws.ec2.model.SecurityGroupId;
import com.atlassian.aws.ec2.model.SubnetId;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.ImmutableMultimap;
import com.google.common.collect.Multimap;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.Collection;
import java.util.Collections;

public class InstanceLaunchConfigurationBuilder
{
    private String keyName;
    private Object userData;
    private double spotInstanceBid = -1;
    private Iterable<EC2InstanceType> instanceType;
    private String imageId;
    private Iterable<String> requestedAvailabilityZone;
    private int startupTimeoutSeconds;
    private Collection<String> availableSubnetIds;
    private int spotRequestTimeoutSeconds = RemoteEC2InstanceImpl.DEFAULT_TIMEOUT;
    private IamInstanceProfileSpecification iamInstanceProfile;
    private boolean isEbsOptimised;
    private String ebsSnapshotId;
    private boolean shouldAssociatePublicIp;
    private ImmutableMultimap<SubnetId, SecurityGroupId> availableSecurityGroups;

    @NotNull
    public InstanceLaunchConfiguration build()
    {
        return new InstanceLaunchConfiguration(
                imageId, keyName, availableSecurityGroups, requestedAvailabilityZone,
                startupTimeoutSeconds, availableSubnetIds, spotRequestTimeoutSeconds, userData, spotInstanceBid,
                instanceType, iamInstanceProfile, ebsSnapshotId, isEbsOptimised,
                shouldAssociatePublicIp);
    }

    public InstanceLaunchConfigurationBuilder withImageId(String imageId)
    {
        this.imageId = imageId;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withKeyName(String keyName)
    {
        this.keyName = keyName;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withAvailableSecurityGroups(final Multimap<SubnetId, SecurityGroupId> availableSecurityGroups)
    {
        this.availableSecurityGroups = ImmutableMultimap.copyOf(availableSecurityGroups);
        return this;
    }

    public InstanceLaunchConfigurationBuilder withUserData(Object userData)
    {
        this.userData = userData;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withInstanceTypes(Iterable<EC2InstanceType> instanceTypes)
    {
        this.instanceType = instanceTypes;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withAvailabilityZone(@Nullable final Iterable<String> availabilityZone)
    {
        this.requestedAvailabilityZone = MoreObjects.firstNonNull(ImmutableList.copyOf(availabilityZone), Collections.<String>emptyList());
        return this;
    }

    public InstanceLaunchConfigurationBuilder withStartupTimeoutSeconds(int startupTimeoutSeconds)
    {
        this.startupTimeoutSeconds = startupTimeoutSeconds;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withSpotInstanceBid(double spotInstanceBid)
    {
        this.spotInstanceBid = spotInstanceBid;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withSpotRequestTimeoutSeconds(int spotRequestTimeoutSeconds)
    {
        this.spotRequestTimeoutSeconds = spotRequestTimeoutSeconds;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withAvailableSubnetIds(@NotNull final Iterable<String> availableSubnetIds)
    {
        this.availableSubnetIds = ImmutableList.copyOf(availableSubnetIds);
        return this;
    }

    public InstanceLaunchConfigurationBuilder withIamInstanceProfile(@Nullable final String iamInstanceProfileArnOrName)
    {
        if (iamInstanceProfileArnOrName==null)
        {
            return this;
        }
        final IamInstanceProfileSpecification profile = new IamInstanceProfileSpecification();
        if (iamInstanceProfileArnOrName.startsWith("arn:aws:iam"))
        {
            profile.setArn(iamInstanceProfileArnOrName);
        }
        else
        {
            profile.setName(iamInstanceProfileArnOrName);
        }
        this.iamInstanceProfile = profile;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withEbsSnapsthotId(final String ebsSnapsthotId)
    {
        this.ebsSnapshotId = ebsSnapsthotId;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withEbsOptimised(final boolean isEbsOptimised)
    {
        this.isEbsOptimised = isEbsOptimised;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withShouldAssociatePublicIp(final boolean shouldAssociatePublicIp)
    {
        this.shouldAssociatePublicIp = shouldAssociatePublicIp;
        return this;
    }
}

==> atlassian-aws-1.0.173-sources.jar: com/atlassian/aws/ec2/InstanceLaunchConfigurationBuilder.java <==
package com.atlassian.aws.ec2;

import com.amazonaws.services.ec2.model.IamInstanceProfileSpecification;
import com.amazonaws.services.ec2.model.Tag;
import com.atlassian.aws.ec2.model.SecurityGroupId;
import com.atlassian.aws.ec2.model.SubnetId;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.ImmutableMultimap;
import com.google.common.collect.Multimap;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.Collection;
import java.util.Collections;

public class InstanceLaunchConfigurationBuilder
{
    private String keyName;
    private Object userData;
    private double spotInstanceBid = -1;
    private Iterable<EC2InstanceType> instanceType;
    private String imageId;
    private Iterable<String> requestedAvailabilityZone;
    private int startupTimeoutSeconds;
    private Collection<String> availableSubnetIds;
    private int spotRequestTimeoutSeconds = RemoteEC2InstanceImpl.DEFAULT_TIMEOUT;
    private IamInstanceProfileSpecification iamInstanceProfile;
    private boolean isEbsOptimised;
    private String ebsSnapshotId;
    private boolean shouldAssociatePublicIp;
    private ImmutableMultimap<SubnetId, SecurityGroupId> availableSecurityGroups;
    private Integer rootFsSizeOverride;
    private Tag tag;

    @NotNull
    public InstanceLaunchConfiguration build()
    {
        return new InstanceLaunchConfiguration(
                imageId, keyName, availableSecurityGroups, requestedAvailabilityZone,
                startupTimeoutSeconds, availableSubnetIds, spotRequestTimeoutSeconds, userData, spotInstanceBid,
                instanceType, iamInstanceProfile, ebsSnapshotId, isEbsOptimised,
                shouldAssociatePublicIp, rootFsSizeOverride, tag);
    }

    public InstanceLaunchConfigurationBuilder withImageId(String imageId)
    {
        this.imageId = imageId;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withKeyName(String keyName)
    {
        this.keyName = keyName;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withAvailableSecurityGroups(final Multimap<SubnetId, SecurityGroupId> availableSecurityGroups)
    {
        this.availableSecurityGroups = ImmutableMultimap.copyOf(availableSecurityGroups);
        return this;
    }

    public InstanceLaunchConfigurationBuilder withUserData(Object userData)
    {
        this.userData = userData;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withInstanceTypes(Iterable<EC2InstanceType> instanceTypes)
    {
        this.instanceType = instanceTypes;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withAvailabilityZone(@Nullable final Iterable<String> availabilityZone)
    {
        this.requestedAvailabilityZone = MoreObjects.firstNonNull(ImmutableList.copyOf(availabilityZone), Collections.<String>emptyList());
        return this;
    }

    public InstanceLaunchConfigurationBuilder withStartupTimeoutSeconds(int startupTimeoutSeconds)
    {
        this.startupTimeoutSeconds = startupTimeoutSeconds;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withSpotInstanceBid(double spotInstanceBid)
    {
        this.spotInstanceBid = spotInstanceBid;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withSpotRequestTimeoutSeconds(int spotRequestTimeoutSeconds)
    {
        this.spotRequestTimeoutSeconds = spotRequestTimeoutSeconds;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withAvailableSubnetIds(@NotNull final Iterable<String> availableSubnetIds)
    {
        this.availableSubnetIds = ImmutableList.copyOf(availableSubnetIds);
        return this;
    }

    public InstanceLaunchConfigurationBuilder withIamInstanceProfile(@Nullable final String iamInstanceProfileArnOrName)
    {
        if (iamInstanceProfileArnOrName==null)
        {
            return this;
        }
        final IamInstanceProfileSpecification profile = new IamInstanceProfileSpecification();
        if (iamInstanceProfileArnOrName.startsWith("arn:aws:iam"))
        {
            profile.setArn(iamInstanceProfileArnOrName);
        }
        else
        {
            profile.setName(iamInstanceProfileArnOrName);
        }
        this.iamInstanceProfile = profile;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withEbsSnapsthotId(final String ebsSnapsthotId)
    {
        this.ebsSnapshotId = ebsSnapsthotId;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withEbsOptimised(final boolean isEbsOptimised)
    {
        this.isEbsOptimised = isEbsOptimised;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withShouldAssociatePublicIp(final boolean shouldAssociatePublicIp)
    {
        this.shouldAssociatePublicIp = shouldAssociatePublicIp;
        return this;
    }
    
    public InstanceLaunchConfigurationBuilder withRootFsSizeOverride(@Nullable final Integer rootFsSizeOverride) {
        this.rootFsSizeOverride = rootFsSizeOverride;
        return this;
    }

    public InstanceLaunchConfigurationBuilder withTag(@NotNull final String key, @NotNull final String value) {
        this.tag = new Tag(key, value);
        return this;
    }
}
